@@ -1,6 +1,6 @@
 package Bundle::DateTime;
 
-$VERSION = 0.05;
+$VERSION = 0.06;
 
 1;
 
@@ -28,6 +28,8 @@ DateTime::Format::Baby
 
 DateTime::Format::Builder
 
+DateTime::Format::DBI
+
 DateTime::Format::Epoch
 
 DateTime::Format::Excel
@@ -68,6 +70,8 @@ DateTime::Event::NameDay
 
 DateTime::Event::Sunrise
 
+DateTime::TimeZone::Alias
+
 =head1 DESCRIPTION
 
 This bundle contains all modules related to the DateTime project: base
